%define anolis_release 4

Name:           glade
Version:        3.40.0
Release:        %{anolis_release}%{?dist}
Summary:        User Interface Designer for GTK+

# - /usr/bin/glade is GPLv2+
# - /usr/bin/glade-previewer is LGPLv2+
# - libgladeui-2.so, libgladegtk.so, and libgladepython.so all combine
#   GPLv2+ and LGPLv2+ code, so the resulting binaries are GPLv2+
License:        GPLv2+ and LGPLv2+
URL:            https://glade.gnome.org/
Source0:        https://download.gnome.org/sources/glade/3.40/glade-%{version}.tar.xz

ExcludeArch:    loongarch64

BuildRequires:  desktop-file-utils
BuildRequires:  docbook-style-xsl
BuildRequires:  gcc
BuildRequires:  gettext
BuildRequires:  gjs-devel
BuildRequires:  gtk3-devel
BuildRequires:  gtk-doc
BuildRequires:  itstool
BuildRequires:  libxml2-devel
BuildRequires:  meson
BuildRequires:  python3-devel
BuildRequires:  python3-gobject-devel
BuildRequires:  webkit2gtk4.1-devel
BuildRequires:  /usr/bin/appstream-util
BuildRequires:  /usr/bin/xsltproc

Requires:       %{name}-libs = %{version}-%{release}

%description
Glade is a RAD tool to enable quick and easy development of user interfaces for
the GTK+ toolkit and the GNOME desktop environment.

The user interfaces designed in Glade are saved as XML, which can be used in
numerous programming languages including C, C++, C#, Vala, Java, Perl, Python,
and others.

%package libs
Summary:        Widget library for Glade UI designer

%description    libs
The %{name}-libs package consists of the widgets that compose the Glade GUI as
a separate library to ease the integration of Glade into other applications.

%package devel
Summary:        Development files for %{name}
Requires:       %{name}-libs = %{version}-%{release}

%description    devel
The %{name}-devel package contains libraries and header files for
developing applications that use Glade widget library.

%package doc
Summary:        Documentation files for %{name}
Requires:       %{name} = %{EVR}
BuildArch:      noarch

%description    doc
The %{name}-doc package contains documentation files for %{name}.

%prep
%autosetup -p1
# glade does not use libsoup, no other porting necessary            
sed -i -e 's/webkit2gtk-4.0/webkit2gtk-4.1/' meson.build

%build
%meson -Dgtk_doc=true
%meson_build

%install
%meson_install

%find_lang glade --with-gnome
%generate_compatibility_deps

%check
appstream-util validate-relax --nonet $RPM_BUILD_ROOT%{_datadir}/metainfo/org.gnome.Glade.appdata.xml
desktop-file-validate $RPM_BUILD_ROOT%{_datadir}/applications/org.gnome.Glade.desktop

%files -f glade.lang
%license COPYING*
%{_bindir}/glade
%{_bindir}/glade-previewer
%{abidir}/glade-previewer-option.list
%{_datadir}/applications/org.gnome.Glade.desktop
%{_datadir}/icons/hicolor/scalable/apps/org.gnome.Glade.svg
%{_datadir}/icons/hicolor/symbolic/apps/glade-brand-symbolic.svg
%{_datadir}/icons/hicolor/symbolic/apps/org.gnome.Glade-symbolic.svg
%{_datadir}/metainfo/org.gnome.Glade.appdata.xml
%{_mandir}/man1/glade.1*
%{_mandir}/man1/glade-previewer*

%files libs
%license COPYING*
%dir %{_libdir}/girepository-1.0
%{_libdir}/girepository-1.0/Gladeui-2.0.typelib
%dir %{_libdir}/glade/
%dir %{_libdir}/glade/modules/
%{_libdir}/glade/modules/libgladegjs.so
%{_libdir}/glade/modules/libgladegtk.so
%{_libdir}/glade/modules/libgladepython.so
%{_libdir}/glade/modules/libgladewebkit2gtk.so
%{_libdir}/libgladeui-2.so.13*
%{_datadir}/glade/
%dir %{abidir}
%{abidir}/libgladegjs.dump
%{abidir}/libgladegtk.dump
%{abidir}/libgladepython.dump
%{abidir}/libgladewebkit2gtk.dump
%{abidir}/libgladeui-2.dump

%files devel
%{_includedir}/libgladeui-2.0/
%{_libdir}/libgladeui-2.so
%{_libdir}/pkgconfig/gladeui-2.0.pc
%dir %{_datadir}/gettext
%dir %{_datadir}/gettext/its
%{_datadir}/gettext/its/glade-catalog.its
%{_datadir}/gettext/its/glade-catalog.loc
%dir %{_datadir}/gir-1.0
%{_datadir}/gir-1.0/Gladeui-2.0.gir
%doc %{_datadir}/gtk-doc/

%files doc
%doc AUTHORS NEWS

%changelog
* Fri Jun 20 2025 mgb01105731 <mgb01105731@alibaba-inc.com> - 3.40.0-4
- Rebuild with webkitgtk 2.48.1
- exclude loongarch64

* Fri Mar 15 2024 Bo Ren <rb01097748@alibaba-inc.com> - 3.40.0-3
- Rebuild with python3.11

* Mon Oct 23 2023 Wenlong Zhang<zhangwenlong@loongson.cn> - 3.40.0-2
- rebuild

* Tue Mar 21 2023 Yuanhong Peng <yummypeng@linux.alibaba.com> - 3.40.0-1
- Init from upstream
